.. image:: https://github.com/thonny/thonny/blob/master/thonny/res/Ukraine.png

`Support Ukraine! <https://github.com/thonny/thonny/wiki/Support-Ukraine>`_

======
Thonny
======

Thonny is a Python `IDE <https://en.wikipedia.org/wiki/Integrated_development_environment>`_ meant for learning programming.


End users
---------
See https://thonny.org and `wiki <https://github.com/thonny/thonny/wiki>`_ for more info.


Contributors
------------
Contributions are welcome! See `CONTRIBUTING.rst <https://github.com/thonny/thonny/blob/master/CONTRIBUTING.rst>`_ for more info.


Sponsors
----------
You can sponsor development of Thonny by sending a donation to Thonny's main author Aivar Annamaa: https://github.com/thonny/thonny/wiki/Sponsors
